# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'FrameworkControl',
    'FrameworkControlInputParameter',
    'FrameworkControlScope',
    'PlanAdvancedBackupSetting',
    'PlanRule',
    'PlanRuleCopyAction',
    'PlanRuleCopyActionLifecycle',
    'PlanRuleLifecycle',
    'ReportPlanReportDeliveryChannel',
    'ReportPlanReportSetting',
    'SelectionCondition',
    'SelectionConditionStringEqual',
    'SelectionConditionStringLike',
    'SelectionConditionStringNotEqual',
    'SelectionConditionStringNotLike',
    'SelectionSelectionTag',
    'GetFrameworkControlResult',
    'GetFrameworkControlInputParameterResult',
    'GetFrameworkControlScopeResult',
    'GetReportPlanReportDeliveryChannelResult',
    'GetReportPlanReportSettingResult',
]

@pulumi.output_type
class FrameworkControl(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "inputParameters":
            suggest = "input_parameters"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FrameworkControl. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FrameworkControl.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FrameworkControl.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: str,
                 input_parameters: Optional[Sequence['outputs.FrameworkControlInputParameter']] = None,
                 scope: Optional['outputs.FrameworkControlScope'] = None):
        """
        :param str name: The unique name of the framework. The name must be between 1 and 256 characters, starting with a letter, and consisting of letters, numbers, and underscores.
        :param Sequence['FrameworkControlInputParameterArgs'] input_parameters: One or more input parameter blocks. An example of a control with two parameters is: "backup plan frequency is at least daily and the retention period is at least 1 year". The first parameter is daily. The second parameter is 1 year. Detailed below.
        :param 'FrameworkControlScopeArgs' scope: The scope of a control. The control scope defines what the control will evaluate. Three examples of control scopes are: a specific backup plan, all backup plans with a specific tag, or all backup plans. Detailed below.
        """
        pulumi.set(__self__, "name", name)
        if input_parameters is not None:
            pulumi.set(__self__, "input_parameters", input_parameters)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The unique name of the framework. The name must be between 1 and 256 characters, starting with a letter, and consisting of letters, numbers, and underscores.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="inputParameters")
    def input_parameters(self) -> Optional[Sequence['outputs.FrameworkControlInputParameter']]:
        """
        One or more input parameter blocks. An example of a control with two parameters is: "backup plan frequency is at least daily and the retention period is at least 1 year". The first parameter is daily. The second parameter is 1 year. Detailed below.
        """
        return pulumi.get(self, "input_parameters")

    @property
    @pulumi.getter
    def scope(self) -> Optional['outputs.FrameworkControlScope']:
        """
        The scope of a control. The control scope defines what the control will evaluate. Three examples of control scopes are: a specific backup plan, all backup plans with a specific tag, or all backup plans. Detailed below.
        """
        return pulumi.get(self, "scope")


@pulumi.output_type
class FrameworkControlInputParameter(dict):
    def __init__(__self__, *,
                 name: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str name: The unique name of the framework. The name must be between 1 and 256 characters, starting with a letter, and consisting of letters, numbers, and underscores.
        :param str value: The value of parameter, for example, hourly.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The unique name of the framework. The name must be between 1 and 256 characters, starting with a letter, and consisting of letters, numbers, and underscores.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The value of parameter, for example, hourly.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class FrameworkControlScope(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "complianceResourceIds":
            suggest = "compliance_resource_ids"
        elif key == "complianceResourceTypes":
            suggest = "compliance_resource_types"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FrameworkControlScope. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FrameworkControlScope.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FrameworkControlScope.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 compliance_resource_ids: Optional[Sequence[str]] = None,
                 compliance_resource_types: Optional[Sequence[str]] = None,
                 tags: Optional[Mapping[str, str]] = None):
        """
        :param Sequence[str] compliance_resource_ids: The ID of the only AWS resource that you want your control scope to contain. Minimum number of 1 item. Maximum number of 100 items.
        :param Sequence[str] compliance_resource_types: Describes whether the control scope includes one or more types of resources, such as EFS or RDS.
        :param Mapping[str, str] tags: Metadata that you can assign to help organize the frameworks you create. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        if compliance_resource_ids is not None:
            pulumi.set(__self__, "compliance_resource_ids", compliance_resource_ids)
        if compliance_resource_types is not None:
            pulumi.set(__self__, "compliance_resource_types", compliance_resource_types)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="complianceResourceIds")
    def compliance_resource_ids(self) -> Optional[Sequence[str]]:
        """
        The ID of the only AWS resource that you want your control scope to contain. Minimum number of 1 item. Maximum number of 100 items.
        """
        return pulumi.get(self, "compliance_resource_ids")

    @property
    @pulumi.getter(name="complianceResourceTypes")
    def compliance_resource_types(self) -> Optional[Sequence[str]]:
        """
        Describes whether the control scope includes one or more types of resources, such as EFS or RDS.
        """
        return pulumi.get(self, "compliance_resource_types")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        """
        Metadata that you can assign to help organize the frameworks you create. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")


@pulumi.output_type
class PlanAdvancedBackupSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "backupOptions":
            suggest = "backup_options"
        elif key == "resourceType":
            suggest = "resource_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanAdvancedBackupSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanAdvancedBackupSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanAdvancedBackupSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 backup_options: Mapping[str, str],
                 resource_type: str):
        """
        :param Mapping[str, str] backup_options: Specifies the backup option for a selected resource. This option is only available for Windows VSS backup jobs. Set to `{ WindowsVSS = "enabled" }` to enable Windows VSS backup option and create a VSS Windows backup.
        :param str resource_type: The type of AWS resource to be backed up. For VSS Windows backups, the only supported resource type is Amazon EC2. Valid values: `EC2`.
        """
        pulumi.set(__self__, "backup_options", backup_options)
        pulumi.set(__self__, "resource_type", resource_type)

    @property
    @pulumi.getter(name="backupOptions")
    def backup_options(self) -> Mapping[str, str]:
        """
        Specifies the backup option for a selected resource. This option is only available for Windows VSS backup jobs. Set to `{ WindowsVSS = "enabled" }` to enable Windows VSS backup option and create a VSS Windows backup.
        """
        return pulumi.get(self, "backup_options")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> str:
        """
        The type of AWS resource to be backed up. For VSS Windows backups, the only supported resource type is Amazon EC2. Valid values: `EC2`.
        """
        return pulumi.get(self, "resource_type")


@pulumi.output_type
class PlanRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ruleName":
            suggest = "rule_name"
        elif key == "targetVaultName":
            suggest = "target_vault_name"
        elif key == "completionWindow":
            suggest = "completion_window"
        elif key == "copyActions":
            suggest = "copy_actions"
        elif key == "enableContinuousBackup":
            suggest = "enable_continuous_backup"
        elif key == "recoveryPointTags":
            suggest = "recovery_point_tags"
        elif key == "startWindow":
            suggest = "start_window"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rule_name: str,
                 target_vault_name: str,
                 completion_window: Optional[int] = None,
                 copy_actions: Optional[Sequence['outputs.PlanRuleCopyAction']] = None,
                 enable_continuous_backup: Optional[bool] = None,
                 lifecycle: Optional['outputs.PlanRuleLifecycle'] = None,
                 recovery_point_tags: Optional[Mapping[str, str]] = None,
                 schedule: Optional[str] = None,
                 start_window: Optional[int] = None):
        """
        :param str rule_name: An display name for a backup rule.
        :param str target_vault_name: The name of a logical container where backups are stored.
        :param int completion_window: The amount of time in minutes AWS Backup attempts a backup before canceling the job and returning an error.
        :param Sequence['PlanRuleCopyActionArgs'] copy_actions: Configuration block(s) with copy operation settings. Detailed below.
        :param bool enable_continuous_backup: Enable continuous backups for supported resources.
        :param 'PlanRuleLifecycleArgs' lifecycle: The lifecycle defines when a protected resource is transitioned to cold storage and when it expires.  Fields documented below.
        :param Mapping[str, str] recovery_point_tags: Metadata that you can assign to help organize the resources that you create.
        :param str schedule: A CRON expression specifying when AWS Backup initiates a backup job.
        :param int start_window: The amount of time in minutes before beginning a backup.
        """
        pulumi.set(__self__, "rule_name", rule_name)
        pulumi.set(__self__, "target_vault_name", target_vault_name)
        if completion_window is not None:
            pulumi.set(__self__, "completion_window", completion_window)
        if copy_actions is not None:
            pulumi.set(__self__, "copy_actions", copy_actions)
        if enable_continuous_backup is not None:
            pulumi.set(__self__, "enable_continuous_backup", enable_continuous_backup)
        if lifecycle is not None:
            pulumi.set(__self__, "lifecycle", lifecycle)
        if recovery_point_tags is not None:
            pulumi.set(__self__, "recovery_point_tags", recovery_point_tags)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if start_window is not None:
            pulumi.set(__self__, "start_window", start_window)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> str:
        """
        An display name for a backup rule.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="targetVaultName")
    def target_vault_name(self) -> str:
        """
        The name of a logical container where backups are stored.
        """
        return pulumi.get(self, "target_vault_name")

    @property
    @pulumi.getter(name="completionWindow")
    def completion_window(self) -> Optional[int]:
        """
        The amount of time in minutes AWS Backup attempts a backup before canceling the job and returning an error.
        """
        return pulumi.get(self, "completion_window")

    @property
    @pulumi.getter(name="copyActions")
    def copy_actions(self) -> Optional[Sequence['outputs.PlanRuleCopyAction']]:
        """
        Configuration block(s) with copy operation settings. Detailed below.
        """
        return pulumi.get(self, "copy_actions")

    @property
    @pulumi.getter(name="enableContinuousBackup")
    def enable_continuous_backup(self) -> Optional[bool]:
        """
        Enable continuous backups for supported resources.
        """
        return pulumi.get(self, "enable_continuous_backup")

    @property
    @pulumi.getter
    def lifecycle(self) -> Optional['outputs.PlanRuleLifecycle']:
        """
        The lifecycle defines when a protected resource is transitioned to cold storage and when it expires.  Fields documented below.
        """
        return pulumi.get(self, "lifecycle")

    @property
    @pulumi.getter(name="recoveryPointTags")
    def recovery_point_tags(self) -> Optional[Mapping[str, str]]:
        """
        Metadata that you can assign to help organize the resources that you create.
        """
        return pulumi.get(self, "recovery_point_tags")

    @property
    @pulumi.getter
    def schedule(self) -> Optional[str]:
        """
        A CRON expression specifying when AWS Backup initiates a backup job.
        """
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="startWindow")
    def start_window(self) -> Optional[int]:
        """
        The amount of time in minutes before beginning a backup.
        """
        return pulumi.get(self, "start_window")


@pulumi.output_type
class PlanRuleCopyAction(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationVaultArn":
            suggest = "destination_vault_arn"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanRuleCopyAction. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanRuleCopyAction.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanRuleCopyAction.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_vault_arn: str,
                 lifecycle: Optional['outputs.PlanRuleCopyActionLifecycle'] = None):
        """
        :param str destination_vault_arn: An Amazon Resource Name (ARN) that uniquely identifies the destination backup vault for the copied backup.
        :param 'PlanRuleCopyActionLifecycleArgs' lifecycle: The lifecycle defines when a protected resource is transitioned to cold storage and when it expires.  Fields documented below.
        """
        pulumi.set(__self__, "destination_vault_arn", destination_vault_arn)
        if lifecycle is not None:
            pulumi.set(__self__, "lifecycle", lifecycle)

    @property
    @pulumi.getter(name="destinationVaultArn")
    def destination_vault_arn(self) -> str:
        """
        An Amazon Resource Name (ARN) that uniquely identifies the destination backup vault for the copied backup.
        """
        return pulumi.get(self, "destination_vault_arn")

    @property
    @pulumi.getter
    def lifecycle(self) -> Optional['outputs.PlanRuleCopyActionLifecycle']:
        """
        The lifecycle defines when a protected resource is transitioned to cold storage and when it expires.  Fields documented below.
        """
        return pulumi.get(self, "lifecycle")


@pulumi.output_type
class PlanRuleCopyActionLifecycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "coldStorageAfter":
            suggest = "cold_storage_after"
        elif key == "deleteAfter":
            suggest = "delete_after"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanRuleCopyActionLifecycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanRuleCopyActionLifecycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanRuleCopyActionLifecycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cold_storage_after: Optional[int] = None,
                 delete_after: Optional[int] = None):
        """
        :param int cold_storage_after: Specifies the number of days after creation that a recovery point is moved to cold storage.
        :param int delete_after: Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
        """
        if cold_storage_after is not None:
            pulumi.set(__self__, "cold_storage_after", cold_storage_after)
        if delete_after is not None:
            pulumi.set(__self__, "delete_after", delete_after)

    @property
    @pulumi.getter(name="coldStorageAfter")
    def cold_storage_after(self) -> Optional[int]:
        """
        Specifies the number of days after creation that a recovery point is moved to cold storage.
        """
        return pulumi.get(self, "cold_storage_after")

    @property
    @pulumi.getter(name="deleteAfter")
    def delete_after(self) -> Optional[int]:
        """
        Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
        """
        return pulumi.get(self, "delete_after")


@pulumi.output_type
class PlanRuleLifecycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "coldStorageAfter":
            suggest = "cold_storage_after"
        elif key == "deleteAfter":
            suggest = "delete_after"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PlanRuleLifecycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PlanRuleLifecycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PlanRuleLifecycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cold_storage_after: Optional[int] = None,
                 delete_after: Optional[int] = None):
        """
        :param int cold_storage_after: Specifies the number of days after creation that a recovery point is moved to cold storage.
        :param int delete_after: Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
        """
        if cold_storage_after is not None:
            pulumi.set(__self__, "cold_storage_after", cold_storage_after)
        if delete_after is not None:
            pulumi.set(__self__, "delete_after", delete_after)

    @property
    @pulumi.getter(name="coldStorageAfter")
    def cold_storage_after(self) -> Optional[int]:
        """
        Specifies the number of days after creation that a recovery point is moved to cold storage.
        """
        return pulumi.get(self, "cold_storage_after")

    @property
    @pulumi.getter(name="deleteAfter")
    def delete_after(self) -> Optional[int]:
        """
        Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
        """
        return pulumi.get(self, "delete_after")


@pulumi.output_type
class ReportPlanReportDeliveryChannel(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "s3BucketName":
            suggest = "s3_bucket_name"
        elif key == "s3KeyPrefix":
            suggest = "s3_key_prefix"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ReportPlanReportDeliveryChannel. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ReportPlanReportDeliveryChannel.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ReportPlanReportDeliveryChannel.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 s3_bucket_name: str,
                 formats: Optional[Sequence[str]] = None,
                 s3_key_prefix: Optional[str] = None):
        """
        :param str s3_bucket_name: The unique name of the S3 bucket that receives your reports.
        :param Sequence[str] formats: A list of the format of your reports: CSV, JSON, or both. If not specified, the default format is CSV.
        :param str s3_key_prefix: The prefix for where Backup Audit Manager delivers your reports to Amazon S3. The prefix is this part of the following path: s3://your-bucket-name/prefix/Backup/us-west-2/year/month/day/report-name. If not specified, there is no prefix.
        """
        pulumi.set(__self__, "s3_bucket_name", s3_bucket_name)
        if formats is not None:
            pulumi.set(__self__, "formats", formats)
        if s3_key_prefix is not None:
            pulumi.set(__self__, "s3_key_prefix", s3_key_prefix)

    @property
    @pulumi.getter(name="s3BucketName")
    def s3_bucket_name(self) -> str:
        """
        The unique name of the S3 bucket that receives your reports.
        """
        return pulumi.get(self, "s3_bucket_name")

    @property
    @pulumi.getter
    def formats(self) -> Optional[Sequence[str]]:
        """
        A list of the format of your reports: CSV, JSON, or both. If not specified, the default format is CSV.
        """
        return pulumi.get(self, "formats")

    @property
    @pulumi.getter(name="s3KeyPrefix")
    def s3_key_prefix(self) -> Optional[str]:
        """
        The prefix for where Backup Audit Manager delivers your reports to Amazon S3. The prefix is this part of the following path: s3://your-bucket-name/prefix/Backup/us-west-2/year/month/day/report-name. If not specified, there is no prefix.
        """
        return pulumi.get(self, "s3_key_prefix")


@pulumi.output_type
class ReportPlanReportSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "reportTemplate":
            suggest = "report_template"
        elif key == "frameworkArns":
            suggest = "framework_arns"
        elif key == "numberOfFrameworks":
            suggest = "number_of_frameworks"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ReportPlanReportSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ReportPlanReportSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ReportPlanReportSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 report_template: str,
                 framework_arns: Optional[Sequence[str]] = None,
                 number_of_frameworks: Optional[int] = None):
        """
        :param str report_template: Identifies the report template for the report. Reports are built using a report template. The report templates are: `RESOURCE_COMPLIANCE_REPORT` | `CONTROL_COMPLIANCE_REPORT` | `BACKUP_JOB_REPORT` | `COPY_JOB_REPORT` | `RESTORE_JOB_REPORT`.
        :param Sequence[str] framework_arns: Specifies the Amazon Resource Names (ARNs) of the frameworks a report covers.
        :param int number_of_frameworks: Specifies the number of frameworks a report covers.
        """
        pulumi.set(__self__, "report_template", report_template)
        if framework_arns is not None:
            pulumi.set(__self__, "framework_arns", framework_arns)
        if number_of_frameworks is not None:
            pulumi.set(__self__, "number_of_frameworks", number_of_frameworks)

    @property
    @pulumi.getter(name="reportTemplate")
    def report_template(self) -> str:
        """
        Identifies the report template for the report. Reports are built using a report template. The report templates are: `RESOURCE_COMPLIANCE_REPORT` | `CONTROL_COMPLIANCE_REPORT` | `BACKUP_JOB_REPORT` | `COPY_JOB_REPORT` | `RESTORE_JOB_REPORT`.
        """
        return pulumi.get(self, "report_template")

    @property
    @pulumi.getter(name="frameworkArns")
    def framework_arns(self) -> Optional[Sequence[str]]:
        """
        Specifies the Amazon Resource Names (ARNs) of the frameworks a report covers.
        """
        return pulumi.get(self, "framework_arns")

    @property
    @pulumi.getter(name="numberOfFrameworks")
    def number_of_frameworks(self) -> Optional[int]:
        """
        Specifies the number of frameworks a report covers.
        """
        return pulumi.get(self, "number_of_frameworks")


@pulumi.output_type
class SelectionCondition(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "stringEquals":
            suggest = "string_equals"
        elif key == "stringLikes":
            suggest = "string_likes"
        elif key == "stringNotEquals":
            suggest = "string_not_equals"
        elif key == "stringNotLikes":
            suggest = "string_not_likes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SelectionCondition. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SelectionCondition.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SelectionCondition.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 string_equals: Optional[Sequence['outputs.SelectionConditionStringEqual']] = None,
                 string_likes: Optional[Sequence['outputs.SelectionConditionStringLike']] = None,
                 string_not_equals: Optional[Sequence['outputs.SelectionConditionStringNotEqual']] = None,
                 string_not_likes: Optional[Sequence['outputs.SelectionConditionStringNotLike']] = None):
        if string_equals is not None:
            pulumi.set(__self__, "string_equals", string_equals)
        if string_likes is not None:
            pulumi.set(__self__, "string_likes", string_likes)
        if string_not_equals is not None:
            pulumi.set(__self__, "string_not_equals", string_not_equals)
        if string_not_likes is not None:
            pulumi.set(__self__, "string_not_likes", string_not_likes)

    @property
    @pulumi.getter(name="stringEquals")
    def string_equals(self) -> Optional[Sequence['outputs.SelectionConditionStringEqual']]:
        return pulumi.get(self, "string_equals")

    @property
    @pulumi.getter(name="stringLikes")
    def string_likes(self) -> Optional[Sequence['outputs.SelectionConditionStringLike']]:
        return pulumi.get(self, "string_likes")

    @property
    @pulumi.getter(name="stringNotEquals")
    def string_not_equals(self) -> Optional[Sequence['outputs.SelectionConditionStringNotEqual']]:
        return pulumi.get(self, "string_not_equals")

    @property
    @pulumi.getter(name="stringNotLikes")
    def string_not_likes(self) -> Optional[Sequence['outputs.SelectionConditionStringNotLike']]:
        return pulumi.get(self, "string_not_likes")


@pulumi.output_type
class SelectionConditionStringEqual(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SelectionConditionStringLike(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SelectionConditionStringNotEqual(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SelectionConditionStringNotLike(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SelectionSelectionTag(dict):
    def __init__(__self__, *,
                 key: str,
                 type: str,
                 value: str):
        """
        :param str key: The key in a key-value pair.
        :param str type: An operation, such as `StringEquals`, that is applied to a key-value pair used to filter resources in a selection.
        :param str value: The value in a key-value pair.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The key in a key-value pair.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        An operation, such as `StringEquals`, that is applied to a key-value pair used to filter resources in a selection.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value in a key-value pair.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetFrameworkControlResult(dict):
    def __init__(__self__, *,
                 input_parameters: Sequence['outputs.GetFrameworkControlInputParameterResult'],
                 name: str,
                 scopes: Sequence['outputs.GetFrameworkControlScopeResult']):
        """
        :param Sequence['GetFrameworkControlInputParameterArgs'] input_parameters: One or more input parameter blocks. An example of a control with two parameters is: "backup plan frequency is at least daily and the retention period is at least 1 year". The first parameter is daily. The second parameter is 1 year. Detailed below.
        :param str name: Backup framework name.
        :param Sequence['GetFrameworkControlScopeArgs'] scopes: Scope of a control. The control scope defines what the control will evaluate. Three examples of control scopes are: a specific backup plan, all backup plans with a specific tag, or all backup plans. Detailed below.
        """
        pulumi.set(__self__, "input_parameters", input_parameters)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "scopes", scopes)

    @property
    @pulumi.getter(name="inputParameters")
    def input_parameters(self) -> Sequence['outputs.GetFrameworkControlInputParameterResult']:
        """
        One or more input parameter blocks. An example of a control with two parameters is: "backup plan frequency is at least daily and the retention period is at least 1 year". The first parameter is daily. The second parameter is 1 year. Detailed below.
        """
        return pulumi.get(self, "input_parameters")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Backup framework name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def scopes(self) -> Sequence['outputs.GetFrameworkControlScopeResult']:
        """
        Scope of a control. The control scope defines what the control will evaluate. Three examples of control scopes are: a specific backup plan, all backup plans with a specific tag, or all backup plans. Detailed below.
        """
        return pulumi.get(self, "scopes")


@pulumi.output_type
class GetFrameworkControlInputParameterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 value: str):
        """
        :param str name: Backup framework name.
        :param str value: Value of parameter, for example, hourly.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Backup framework name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Value of parameter, for example, hourly.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetFrameworkControlScopeResult(dict):
    def __init__(__self__, *,
                 compliance_resource_ids: Sequence[str],
                 compliance_resource_types: Sequence[str],
                 tags: Mapping[str, str]):
        """
        :param Sequence[str] compliance_resource_ids: The ID of the only AWS resource that you want your control scope to contain.
        :param Sequence[str] compliance_resource_types: Describes whether the control scope includes one or more types of resources, such as EFS or RDS.
        :param Mapping[str, str] tags: Tag key-value pair applied to those AWS resources that you want to trigger an evaluation for a rule. A maximum of one key-value pair can be provided.
        """
        pulumi.set(__self__, "compliance_resource_ids", compliance_resource_ids)
        pulumi.set(__self__, "compliance_resource_types", compliance_resource_types)
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="complianceResourceIds")
    def compliance_resource_ids(self) -> Sequence[str]:
        """
        The ID of the only AWS resource that you want your control scope to contain.
        """
        return pulumi.get(self, "compliance_resource_ids")

    @property
    @pulumi.getter(name="complianceResourceTypes")
    def compliance_resource_types(self) -> Sequence[str]:
        """
        Describes whether the control scope includes one or more types of resources, such as EFS or RDS.
        """
        return pulumi.get(self, "compliance_resource_types")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        Tag key-value pair applied to those AWS resources that you want to trigger an evaluation for a rule. A maximum of one key-value pair can be provided.
        """
        return pulumi.get(self, "tags")


@pulumi.output_type
class GetReportPlanReportDeliveryChannelResult(dict):
    def __init__(__self__, *,
                 formats: Sequence[str],
                 s3_bucket_name: str,
                 s3_key_prefix: str):
        """
        :param Sequence[str] formats: List of the format of your reports: CSV, JSON, or both.
        :param str s3_bucket_name: Unique name of the S3 bucket that receives your reports.
        :param str s3_key_prefix: Prefix for where Backup Audit Manager delivers your reports to Amazon S3. The prefix is this part of the following path: s3://your-bucket-name/prefix/Backup/us-west-2/year/month/day/report-name.
        """
        pulumi.set(__self__, "formats", formats)
        pulumi.set(__self__, "s3_bucket_name", s3_bucket_name)
        pulumi.set(__self__, "s3_key_prefix", s3_key_prefix)

    @property
    @pulumi.getter
    def formats(self) -> Sequence[str]:
        """
        List of the format of your reports: CSV, JSON, or both.
        """
        return pulumi.get(self, "formats")

    @property
    @pulumi.getter(name="s3BucketName")
    def s3_bucket_name(self) -> str:
        """
        Unique name of the S3 bucket that receives your reports.
        """
        return pulumi.get(self, "s3_bucket_name")

    @property
    @pulumi.getter(name="s3KeyPrefix")
    def s3_key_prefix(self) -> str:
        """
        Prefix for where Backup Audit Manager delivers your reports to Amazon S3. The prefix is this part of the following path: s3://your-bucket-name/prefix/Backup/us-west-2/year/month/day/report-name.
        """
        return pulumi.get(self, "s3_key_prefix")


@pulumi.output_type
class GetReportPlanReportSettingResult(dict):
    def __init__(__self__, *,
                 framework_arns: Sequence[str],
                 number_of_frameworks: int,
                 report_template: str):
        """
        :param Sequence[str] framework_arns: ARNs of the frameworks a report covers.
        :param int number_of_frameworks: Specifies the number of frameworks a report covers.
        :param str report_template: Identifies the report template for the report. Reports are built using a report template.
        """
        pulumi.set(__self__, "framework_arns", framework_arns)
        pulumi.set(__self__, "number_of_frameworks", number_of_frameworks)
        pulumi.set(__self__, "report_template", report_template)

    @property
    @pulumi.getter(name="frameworkArns")
    def framework_arns(self) -> Sequence[str]:
        """
        ARNs of the frameworks a report covers.
        """
        return pulumi.get(self, "framework_arns")

    @property
    @pulumi.getter(name="numberOfFrameworks")
    def number_of_frameworks(self) -> int:
        """
        Specifies the number of frameworks a report covers.
        """
        return pulumi.get(self, "number_of_frameworks")

    @property
    @pulumi.getter(name="reportTemplate")
    def report_template(self) -> str:
        """
        Identifies the report template for the report. Reports are built using a report template.
        """
        return pulumi.get(self, "report_template")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetSubnetGroupResult',
    'AwaitableGetSubnetGroupResult',
    'get_subnet_group',
    'get_subnet_group_output',
]

@pulumi.output_type
class GetSubnetGroupResult:
    """
    A collection of values returned by getSubnetGroup.
    """
    def __init__(__self__, arn=None, description=None, id=None, name=None, subnet_ids=None, tags=None, vpc_id=None):
        if arn and not isinstance(arn, str):
            raise TypeError("Expected argument 'arn' to be a str")
        pulumi.set(__self__, "arn", arn)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if subnet_ids and not isinstance(subnet_ids, list):
            raise TypeError("Expected argument 'subnet_ids' to be a list")
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def arn(self) -> str:
        """
        ARN of the subnet group.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the subnet group.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Sequence[str]:
        """
        Set of VPC Subnet ID-s of the subnet group.
        """
        return pulumi.get(self, "subnet_ids")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        Map of tags assigned to the subnet group.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        VPC in which the subnet group exists.
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetSubnetGroupResult(GetSubnetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSubnetGroupResult(
            arn=self.arn,
            description=self.description,
            id=self.id,
            name=self.name,
            subnet_ids=self.subnet_ids,
            tags=self.tags,
            vpc_id=self.vpc_id)


def get_subnet_group(name: Optional[str] = None,
                     tags: Optional[Mapping[str, str]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSubnetGroupResult:
    """
    Provides information about a MemoryDB Subnet Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.memorydb.get_subnet_group(name="my-subnet-group")
    ```


    :param str name: Name of the subnet group.
    :param Mapping[str, str] tags: Map of tags assigned to the subnet group.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aws:memorydb/getSubnetGroup:getSubnetGroup', __args__, opts=opts, typ=GetSubnetGroupResult).value

    return AwaitableGetSubnetGroupResult(
        arn=__ret__.arn,
        description=__ret__.description,
        id=__ret__.id,
        name=__ret__.name,
        subnet_ids=__ret__.subnet_ids,
        tags=__ret__.tags,
        vpc_id=__ret__.vpc_id)


@_utilities.lift_output_func(get_subnet_group)
def get_subnet_group_output(name: Optional[pulumi.Input[str]] = None,
                            tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSubnetGroupResult]:
    """
    Provides information about a MemoryDB Subnet Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.memorydb.get_subnet_group(name="my-subnet-group")
    ```


    :param str name: Name of the subnet group.
    :param Mapping[str, str] tags: Map of tags assigned to the subnet group.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'RepositoryAssociationKmsKeyDetailsArgs',
    'RepositoryAssociationRepositoryArgs',
    'RepositoryAssociationRepositoryBitbucketArgs',
    'RepositoryAssociationRepositoryCodecommitArgs',
    'RepositoryAssociationRepositoryGithubEnterpriseServerArgs',
    'RepositoryAssociationRepositoryS3BucketArgs',
    'RepositoryAssociationS3RepositoryDetailArgs',
    'RepositoryAssociationS3RepositoryDetailCodeArtifactArgs',
]

@pulumi.input_type
class RepositoryAssociationKmsKeyDetailsArgs:
    def __init__(__self__, *,
                 encryption_option: Optional[pulumi.Input[str]] = None,
                 kms_key_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] encryption_option: The encryption option for a repository association. It is either owned by AWS Key Management Service (KMS) (`AWS_OWNED_CMK`) or customer managed (`CUSTOMER_MANAGED_CMK`).
        :param pulumi.Input[str] kms_key_id: The ID of the AWS KMS key that is associated with a repository association.
        """
        if encryption_option is not None:
            pulumi.set(__self__, "encryption_option", encryption_option)
        if kms_key_id is not None:
            pulumi.set(__self__, "kms_key_id", kms_key_id)

    @property
    @pulumi.getter(name="encryptionOption")
    def encryption_option(self) -> Optional[pulumi.Input[str]]:
        """
        The encryption option for a repository association. It is either owned by AWS Key Management Service (KMS) (`AWS_OWNED_CMK`) or customer managed (`CUSTOMER_MANAGED_CMK`).
        """
        return pulumi.get(self, "encryption_option")

    @encryption_option.setter
    def encryption_option(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encryption_option", value)

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the AWS KMS key that is associated with a repository association.
        """
        return pulumi.get(self, "kms_key_id")

    @kms_key_id.setter
    def kms_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms_key_id", value)


@pulumi.input_type
class RepositoryAssociationRepositoryArgs:
    def __init__(__self__, *,
                 bitbucket: Optional[pulumi.Input['RepositoryAssociationRepositoryBitbucketArgs']] = None,
                 codecommit: Optional[pulumi.Input['RepositoryAssociationRepositoryCodecommitArgs']] = None,
                 github_enterprise_server: Optional[pulumi.Input['RepositoryAssociationRepositoryGithubEnterpriseServerArgs']] = None,
                 s3_bucket: Optional[pulumi.Input['RepositoryAssociationRepositoryS3BucketArgs']] = None):
        if bitbucket is not None:
            pulumi.set(__self__, "bitbucket", bitbucket)
        if codecommit is not None:
            pulumi.set(__self__, "codecommit", codecommit)
        if github_enterprise_server is not None:
            pulumi.set(__self__, "github_enterprise_server", github_enterprise_server)
        if s3_bucket is not None:
            pulumi.set(__self__, "s3_bucket", s3_bucket)

    @property
    @pulumi.getter
    def bitbucket(self) -> Optional[pulumi.Input['RepositoryAssociationRepositoryBitbucketArgs']]:
        return pulumi.get(self, "bitbucket")

    @bitbucket.setter
    def bitbucket(self, value: Optional[pulumi.Input['RepositoryAssociationRepositoryBitbucketArgs']]):
        pulumi.set(self, "bitbucket", value)

    @property
    @pulumi.getter
    def codecommit(self) -> Optional[pulumi.Input['RepositoryAssociationRepositoryCodecommitArgs']]:
        return pulumi.get(self, "codecommit")

    @codecommit.setter
    def codecommit(self, value: Optional[pulumi.Input['RepositoryAssociationRepositoryCodecommitArgs']]):
        pulumi.set(self, "codecommit", value)

    @property
    @pulumi.getter(name="githubEnterpriseServer")
    def github_enterprise_server(self) -> Optional[pulumi.Input['RepositoryAssociationRepositoryGithubEnterpriseServerArgs']]:
        return pulumi.get(self, "github_enterprise_server")

    @github_enterprise_server.setter
    def github_enterprise_server(self, value: Optional[pulumi.Input['RepositoryAssociationRepositoryGithubEnterpriseServerArgs']]):
        pulumi.set(self, "github_enterprise_server", value)

    @property
    @pulumi.getter(name="s3Bucket")
    def s3_bucket(self) -> Optional[pulumi.Input['RepositoryAssociationRepositoryS3BucketArgs']]:
        return pulumi.get(self, "s3_bucket")

    @s3_bucket.setter
    def s3_bucket(self, value: Optional[pulumi.Input['RepositoryAssociationRepositoryS3BucketArgs']]):
        pulumi.set(self, "s3_bucket", value)


@pulumi.input_type
class RepositoryAssociationRepositoryBitbucketArgs:
    def __init__(__self__, *,
                 connection_arn: pulumi.Input[str],
                 name: pulumi.Input[str],
                 owner: pulumi.Input[str]):
        """
        :param pulumi.Input[str] connection_arn: The Amazon Resource Name (ARN) of an AWS CodeStar Connections connection.
        :param pulumi.Input[str] name: The name of the third party source repository.
        :param pulumi.Input[str] owner: The username for the account that owns the repository.
        """
        pulumi.set(__self__, "connection_arn", connection_arn)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "owner", owner)

    @property
    @pulumi.getter(name="connectionArn")
    def connection_arn(self) -> pulumi.Input[str]:
        """
        The Amazon Resource Name (ARN) of an AWS CodeStar Connections connection.
        """
        return pulumi.get(self, "connection_arn")

    @connection_arn.setter
    def connection_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "connection_arn", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the third party source repository.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Input[str]:
        """
        The username for the account that owns the repository.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: pulumi.Input[str]):
        pulumi.set(self, "owner", value)


@pulumi.input_type
class RepositoryAssociationRepositoryCodecommitArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str]):
        """
        :param pulumi.Input[str] name: The name of the AWS CodeCommit repository.
        """
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the AWS CodeCommit repository.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class RepositoryAssociationRepositoryGithubEnterpriseServerArgs:
    def __init__(__self__, *,
                 connection_arn: pulumi.Input[str],
                 name: pulumi.Input[str],
                 owner: pulumi.Input[str]):
        """
        :param pulumi.Input[str] connection_arn: The Amazon Resource Name (ARN) of an AWS CodeStar Connections connection.
        :param pulumi.Input[str] name: The name of the third party source repository.
        :param pulumi.Input[str] owner: The username for the account that owns the repository.
        """
        pulumi.set(__self__, "connection_arn", connection_arn)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "owner", owner)

    @property
    @pulumi.getter(name="connectionArn")
    def connection_arn(self) -> pulumi.Input[str]:
        """
        The Amazon Resource Name (ARN) of an AWS CodeStar Connections connection.
        """
        return pulumi.get(self, "connection_arn")

    @connection_arn.setter
    def connection_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "connection_arn", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the third party source repository.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Input[str]:
        """
        The username for the account that owns the repository.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: pulumi.Input[str]):
        pulumi.set(self, "owner", value)


@pulumi.input_type
class RepositoryAssociationRepositoryS3BucketArgs:
    def __init__(__self__, *,
                 bucket_name: pulumi.Input[str],
                 name: pulumi.Input[str]):
        """
        :param pulumi.Input[str] bucket_name: The name of the S3 bucket used for associating a new S3 repository. Note: The name must begin with `codeguru-reviewer-`.
        :param pulumi.Input[str] name: The name of the third party source repository.
        """
        pulumi.set(__self__, "bucket_name", bucket_name)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> pulumi.Input[str]:
        """
        The name of the S3 bucket used for associating a new S3 repository. Note: The name must begin with `codeguru-reviewer-`.
        """
        return pulumi.get(self, "bucket_name")

    @bucket_name.setter
    def bucket_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "bucket_name", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the third party source repository.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class RepositoryAssociationS3RepositoryDetailArgs:
    def __init__(__self__, *,
                 bucket_name: Optional[pulumi.Input[str]] = None,
                 code_artifacts: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryAssociationS3RepositoryDetailCodeArtifactArgs']]]] = None):
        """
        :param pulumi.Input[str] bucket_name: The name of the S3 bucket used for associating a new S3 repository. Note: The name must begin with `codeguru-reviewer-`.
        """
        if bucket_name is not None:
            pulumi.set(__self__, "bucket_name", bucket_name)
        if code_artifacts is not None:
            pulumi.set(__self__, "code_artifacts", code_artifacts)

    @property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the S3 bucket used for associating a new S3 repository. Note: The name must begin with `codeguru-reviewer-`.
        """
        return pulumi.get(self, "bucket_name")

    @bucket_name.setter
    def bucket_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bucket_name", value)

    @property
    @pulumi.getter(name="codeArtifacts")
    def code_artifacts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryAssociationS3RepositoryDetailCodeArtifactArgs']]]]:
        return pulumi.get(self, "code_artifacts")

    @code_artifacts.setter
    def code_artifacts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryAssociationS3RepositoryDetailCodeArtifactArgs']]]]):
        pulumi.set(self, "code_artifacts", value)


@pulumi.input_type
class RepositoryAssociationS3RepositoryDetailCodeArtifactArgs:
    def __init__(__self__, *,
                 build_artifacts_object_key: Optional[pulumi.Input[str]] = None,
                 source_code_artifacts_object_key: Optional[pulumi.Input[str]] = None):
        if build_artifacts_object_key is not None:
            pulumi.set(__self__, "build_artifacts_object_key", build_artifacts_object_key)
        if source_code_artifacts_object_key is not None:
            pulumi.set(__self__, "source_code_artifacts_object_key", source_code_artifacts_object_key)

    @property
    @pulumi.getter(name="buildArtifactsObjectKey")
    def build_artifacts_object_key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "build_artifacts_object_key")

    @build_artifacts_object_key.setter
    def build_artifacts_object_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "build_artifacts_object_key", value)

    @property
    @pulumi.getter(name="sourceCodeArtifactsObjectKey")
    def source_code_artifacts_object_key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_code_artifacts_object_key")

    @source_code_artifacts_object_key.setter
    def source_code_artifacts_object_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_code_artifacts_object_key", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ResourceSetArgs', 'ResourceSet']

@pulumi.input_type
class ResourceSetArgs:
    def __init__(__self__, *,
                 resource_set_name: pulumi.Input[str],
                 resource_set_type: pulumi.Input[str],
                 resources: pulumi.Input[Sequence[pulumi.Input['ResourceSetResourceArgs']]],
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ResourceSet resource.
        :param pulumi.Input[str] resource_set_name: Unique name describing the resource set.
        :param pulumi.Input[str] resource_set_type: Type of the resources in the resource set.
        :param pulumi.Input[Sequence[pulumi.Input['ResourceSetResourceArgs']]] resources: List of resources to add to this resource set. See below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value mapping of resource tags. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level
        """
        pulumi.set(__self__, "resource_set_name", resource_set_name)
        pulumi.set(__self__, "resource_set_type", resource_set_type)
        pulumi.set(__self__, "resources", resources)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="resourceSetName")
    def resource_set_name(self) -> pulumi.Input[str]:
        """
        Unique name describing the resource set.
        """
        return pulumi.get(self, "resource_set_name")

    @resource_set_name.setter
    def resource_set_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_set_name", value)

    @property
    @pulumi.getter(name="resourceSetType")
    def resource_set_type(self) -> pulumi.Input[str]:
        """
        Type of the resources in the resource set.
        """
        return pulumi.get(self, "resource_set_type")

    @resource_set_type.setter
    def resource_set_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_set_type", value)

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Input[Sequence[pulumi.Input['ResourceSetResourceArgs']]]:
        """
        List of resources to add to this resource set. See below.
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: pulumi.Input[Sequence[pulumi.Input['ResourceSetResourceArgs']]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value mapping of resource tags. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ResourceSetState:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[str]] = None,
                 resource_set_name: Optional[pulumi.Input[str]] = None,
                 resource_set_type: Optional[pulumi.Input[str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceSetResourceArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ResourceSet resources.
        :param pulumi.Input[str] arn: NLB resource ARN.
        :param pulumi.Input[str] resource_set_name: Unique name describing the resource set.
        :param pulumi.Input[str] resource_set_type: Type of the resources in the resource set.
        :param pulumi.Input[Sequence[pulumi.Input['ResourceSetResourceArgs']]] resources: List of resources to add to this resource set. See below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value mapping of resource tags. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: Map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if resource_set_name is not None:
            pulumi.set(__self__, "resource_set_name", resource_set_name)
        if resource_set_type is not None:
            pulumi.set(__self__, "resource_set_type", resource_set_type)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tags_all is not None:
            pulumi.set(__self__, "tags_all", tags_all)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        NLB resource ARN.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter(name="resourceSetName")
    def resource_set_name(self) -> Optional[pulumi.Input[str]]:
        """
        Unique name describing the resource set.
        """
        return pulumi.get(self, "resource_set_name")

    @resource_set_name.setter
    def resource_set_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_set_name", value)

    @property
    @pulumi.getter(name="resourceSetType")
    def resource_set_type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of the resources in the resource set.
        """
        return pulumi.get(self, "resource_set_type")

    @resource_set_type.setter
    def resource_set_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_set_type", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ResourceSetResourceArgs']]]]:
        """
        List of resources to add to this resource set. See below.
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ResourceSetResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value mapping of resource tags. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        return pulumi.get(self, "tags_all")

    @tags_all.setter
    def tags_all(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags_all", value)


class ResourceSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 resource_set_name: Optional[pulumi.Input[str]] = None,
                 resource_set_type: Optional[pulumi.Input[str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ResourceSetResourceArgs']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides an AWS Route 53 Recovery Readiness Resource Set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.route53recoveryreadiness.ResourceSet("example",
            resource_set_name=my_cw_alarm_set,
            resource_set_type="AWS::CloudWatch::Alarm",
            resources=[aws.route53recoveryreadiness.ResourceSetResourceArgs(
                resource_arn=aws_cloudwatch_metric_alarm["example"]["arn"],
            )])
        ```

        ## Import

        Route53 Recovery Readiness resource set name can be imported via the resource set name, e.g.,

        ```sh
         $ pulumi import aws:route53recoveryreadiness/resourceSet:ResourceSet my-cw-alarm-set
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] resource_set_name: Unique name describing the resource set.
        :param pulumi.Input[str] resource_set_type: Type of the resources in the resource set.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ResourceSetResourceArgs']]]] resources: List of resources to add to this resource set. See below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value mapping of resource tags. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ResourceSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an AWS Route 53 Recovery Readiness Resource Set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.route53recoveryreadiness.ResourceSet("example",
            resource_set_name=my_cw_alarm_set,
            resource_set_type="AWS::CloudWatch::Alarm",
            resources=[aws.route53recoveryreadiness.ResourceSetResourceArgs(
                resource_arn=aws_cloudwatch_metric_alarm["example"]["arn"],
            )])
        ```

        ## Import

        Route53 Recovery Readiness resource set name can be imported via the resource set name, e.g.,

        ```sh
         $ pulumi import aws:route53recoveryreadiness/resourceSet:ResourceSet my-cw-alarm-set
        ```

        :param str resource_name: The name of the resource.
        :param ResourceSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ResourceSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 resource_set_name: Optional[pulumi.Input[str]] = None,
                 resource_set_type: Optional[pulumi.Input[str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ResourceSetResourceArgs']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ResourceSetArgs.__new__(ResourceSetArgs)

            if resource_set_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_set_name'")
            __props__.__dict__["resource_set_name"] = resource_set_name
            if resource_set_type is None and not opts.urn:
                raise TypeError("Missing required property 'resource_set_type'")
            __props__.__dict__["resource_set_type"] = resource_set_type
            if resources is None and not opts.urn:
                raise TypeError("Missing required property 'resources'")
            __props__.__dict__["resources"] = resources
            __props__.__dict__["tags"] = tags
            __props__.__dict__["arn"] = None
            __props__.__dict__["tags_all"] = None
        super(ResourceSet, __self__).__init__(
            'aws:route53recoveryreadiness/resourceSet:ResourceSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            arn: Optional[pulumi.Input[str]] = None,
            resource_set_name: Optional[pulumi.Input[str]] = None,
            resource_set_type: Optional[pulumi.Input[str]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ResourceSetResourceArgs']]]]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'ResourceSet':
        """
        Get an existing ResourceSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: NLB resource ARN.
        :param pulumi.Input[str] resource_set_name: Unique name describing the resource set.
        :param pulumi.Input[str] resource_set_type: Type of the resources in the resource set.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ResourceSetResourceArgs']]]] resources: List of resources to add to this resource set. See below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value mapping of resource tags. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: Map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ResourceSetState.__new__(_ResourceSetState)

        __props__.__dict__["arn"] = arn
        __props__.__dict__["resource_set_name"] = resource_set_name
        __props__.__dict__["resource_set_type"] = resource_set_type
        __props__.__dict__["resources"] = resources
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tags_all"] = tags_all
        return ResourceSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Output[str]:
        """
        NLB resource ARN.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="resourceSetName")
    def resource_set_name(self) -> pulumi.Output[str]:
        """
        Unique name describing the resource set.
        """
        return pulumi.get(self, "resource_set_name")

    @property
    @pulumi.getter(name="resourceSetType")
    def resource_set_type(self) -> pulumi.Output[str]:
        """
        Type of the resources in the resource set.
        """
        return pulumi.get(self, "resource_set_type")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Sequence['outputs.ResourceSetResource']]:
        """
        List of resources to add to this resource set. See below.
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Key-value mapping of resource tags. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        return pulumi.get(self, "tags_all")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .bucket import *
from .bucket_access_key import *
from .bucket_resource_access import *
from .certificate import *
from .container_service import *
from .container_service_deployment_version import *
from .database import *
from .disk import *
from .disk_attachment import *
from .domain import *
from .domain_entry import *
from .instance import *
from .instance_public_ports import *
from .key_pair import *
from .lb import *
from .lb_attachment import *
from .lb_certificate import *
from .lb_certificate_attachment import *
from .lb_https_redirection_policy import *
from .lb_stickiness_policy import *
from .static_ip import *
from .static_ip_attachment import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ClusterSnapshotArgs', 'ClusterSnapshot']

@pulumi.input_type
class ClusterSnapshotArgs:
    def __init__(__self__, *,
                 cluster_identifier: pulumi.Input[str],
                 snapshot_identifier: pulumi.Input[str],
                 manual_snapshot_retention_period: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ClusterSnapshot resource.
        :param pulumi.Input[str] cluster_identifier: The cluster identifier for which you want a snapshot.
        :param pulumi.Input[str] snapshot_identifier: A unique identifier for the snapshot that you are requesting. This identifier must be unique for all snapshots within the Amazon Web Services account.
        :param pulumi.Input[int] manual_snapshot_retention_period: The number of days that a manual snapshot is retained. If the value is `-1`, the manual snapshot is retained indefinitely. Valid values are -1 and between `1` and `3653`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        pulumi.set(__self__, "cluster_identifier", cluster_identifier)
        pulumi.set(__self__, "snapshot_identifier", snapshot_identifier)
        if manual_snapshot_retention_period is not None:
            pulumi.set(__self__, "manual_snapshot_retention_period", manual_snapshot_retention_period)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="clusterIdentifier")
    def cluster_identifier(self) -> pulumi.Input[str]:
        """
        The cluster identifier for which you want a snapshot.
        """
        return pulumi.get(self, "cluster_identifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_identifier", value)

    @property
    @pulumi.getter(name="snapshotIdentifier")
    def snapshot_identifier(self) -> pulumi.Input[str]:
        """
        A unique identifier for the snapshot that you are requesting. This identifier must be unique for all snapshots within the Amazon Web Services account.
        """
        return pulumi.get(self, "snapshot_identifier")

    @snapshot_identifier.setter
    def snapshot_identifier(self, value: pulumi.Input[str]):
        pulumi.set(self, "snapshot_identifier", value)

    @property
    @pulumi.getter(name="manualSnapshotRetentionPeriod")
    def manual_snapshot_retention_period(self) -> Optional[pulumi.Input[int]]:
        """
        The number of days that a manual snapshot is retained. If the value is `-1`, the manual snapshot is retained indefinitely. Valid values are -1 and between `1` and `3653`.
        """
        return pulumi.get(self, "manual_snapshot_retention_period")

    @manual_snapshot_retention_period.setter
    def manual_snapshot_retention_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "manual_snapshot_retention_period", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ClusterSnapshotState:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[str]] = None,
                 cluster_identifier: Optional[pulumi.Input[str]] = None,
                 kms_key_id: Optional[pulumi.Input[str]] = None,
                 manual_snapshot_retention_period: Optional[pulumi.Input[int]] = None,
                 owner_account: Optional[pulumi.Input[str]] = None,
                 snapshot_identifier: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ClusterSnapshot resources.
        :param pulumi.Input[str] arn: Amazon Resource Name (ARN) of the snapshot.
        :param pulumi.Input[str] cluster_identifier: The cluster identifier for which you want a snapshot.
        :param pulumi.Input[str] kms_key_id: The Key Management Service (KMS) key ID of the encryption key that was used to encrypt data in the cluster from which the snapshot was taken.
        :param pulumi.Input[int] manual_snapshot_retention_period: The number of days that a manual snapshot is retained. If the value is `-1`, the manual snapshot is retained indefinitely. Valid values are -1 and between `1` and `3653`.
        :param pulumi.Input[str] owner_account: For manual snapshots, the Amazon Web Services account used to create or copy the snapshot. For automatic snapshots, the owner of the cluster. The owner can perform all snapshot actions, such as sharing a manual snapshot.
        :param pulumi.Input[str] snapshot_identifier: A unique identifier for the snapshot that you are requesting. This identifier must be unique for all snapshots within the Amazon Web Services account.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if cluster_identifier is not None:
            pulumi.set(__self__, "cluster_identifier", cluster_identifier)
        if kms_key_id is not None:
            pulumi.set(__self__, "kms_key_id", kms_key_id)
        if manual_snapshot_retention_period is not None:
            pulumi.set(__self__, "manual_snapshot_retention_period", manual_snapshot_retention_period)
        if owner_account is not None:
            pulumi.set(__self__, "owner_account", owner_account)
        if snapshot_identifier is not None:
            pulumi.set(__self__, "snapshot_identifier", snapshot_identifier)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tags_all is not None:
            pulumi.set(__self__, "tags_all", tags_all)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        Amazon Resource Name (ARN) of the snapshot.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter(name="clusterIdentifier")
    def cluster_identifier(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster identifier for which you want a snapshot.
        """
        return pulumi.get(self, "cluster_identifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_identifier", value)

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Key Management Service (KMS) key ID of the encryption key that was used to encrypt data in the cluster from which the snapshot was taken.
        """
        return pulumi.get(self, "kms_key_id")

    @kms_key_id.setter
    def kms_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms_key_id", value)

    @property
    @pulumi.getter(name="manualSnapshotRetentionPeriod")
    def manual_snapshot_retention_period(self) -> Optional[pulumi.Input[int]]:
        """
        The number of days that a manual snapshot is retained. If the value is `-1`, the manual snapshot is retained indefinitely. Valid values are -1 and between `1` and `3653`.
        """
        return pulumi.get(self, "manual_snapshot_retention_period")

    @manual_snapshot_retention_period.setter
    def manual_snapshot_retention_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "manual_snapshot_retention_period", value)

    @property
    @pulumi.getter(name="ownerAccount")
    def owner_account(self) -> Optional[pulumi.Input[str]]:
        """
        For manual snapshots, the Amazon Web Services account used to create or copy the snapshot. For automatic snapshots, the owner of the cluster. The owner can perform all snapshot actions, such as sharing a manual snapshot.
        """
        return pulumi.get(self, "owner_account")

    @owner_account.setter
    def owner_account(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner_account", value)

    @property
    @pulumi.getter(name="snapshotIdentifier")
    def snapshot_identifier(self) -> Optional[pulumi.Input[str]]:
        """
        A unique identifier for the snapshot that you are requesting. This identifier must be unique for all snapshots within the Amazon Web Services account.
        """
        return pulumi.get(self, "snapshot_identifier")

    @snapshot_identifier.setter
    def snapshot_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "snapshot_identifier", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        return pulumi.get(self, "tags_all")

    @tags_all.setter
    def tags_all(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags_all", value)


class ClusterSnapshot(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_identifier: Optional[pulumi.Input[str]] = None,
                 manual_snapshot_retention_period: Optional[pulumi.Input[int]] = None,
                 snapshot_identifier: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Creates a Redshift cluster snapshot

        ## Import

        Redshift Cluster Snapshots support import by `snapshot_identifier`, e.g., console

        ```sh
         $ pulumi import aws:redshift/clusterSnapshot:ClusterSnapshot test example
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_identifier: The cluster identifier for which you want a snapshot.
        :param pulumi.Input[int] manual_snapshot_retention_period: The number of days that a manual snapshot is retained. If the value is `-1`, the manual snapshot is retained indefinitely. Valid values are -1 and between `1` and `3653`.
        :param pulumi.Input[str] snapshot_identifier: A unique identifier for the snapshot that you are requesting. This identifier must be unique for all snapshots within the Amazon Web Services account.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterSnapshotArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a Redshift cluster snapshot

        ## Import

        Redshift Cluster Snapshots support import by `snapshot_identifier`, e.g., console

        ```sh
         $ pulumi import aws:redshift/clusterSnapshot:ClusterSnapshot test example
        ```

        :param str resource_name: The name of the resource.
        :param ClusterSnapshotArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterSnapshotArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_identifier: Optional[pulumi.Input[str]] = None,
                 manual_snapshot_retention_period: Optional[pulumi.Input[int]] = None,
                 snapshot_identifier: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterSnapshotArgs.__new__(ClusterSnapshotArgs)

            if cluster_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_identifier'")
            __props__.__dict__["cluster_identifier"] = cluster_identifier
            __props__.__dict__["manual_snapshot_retention_period"] = manual_snapshot_retention_period
            if snapshot_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'snapshot_identifier'")
            __props__.__dict__["snapshot_identifier"] = snapshot_identifier
            __props__.__dict__["tags"] = tags
            __props__.__dict__["arn"] = None
            __props__.__dict__["kms_key_id"] = None
            __props__.__dict__["owner_account"] = None
            __props__.__dict__["tags_all"] = None
        super(ClusterSnapshot, __self__).__init__(
            'aws:redshift/clusterSnapshot:ClusterSnapshot',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            arn: Optional[pulumi.Input[str]] = None,
            cluster_identifier: Optional[pulumi.Input[str]] = None,
            kms_key_id: Optional[pulumi.Input[str]] = None,
            manual_snapshot_retention_period: Optional[pulumi.Input[int]] = None,
            owner_account: Optional[pulumi.Input[str]] = None,
            snapshot_identifier: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'ClusterSnapshot':
        """
        Get an existing ClusterSnapshot resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: Amazon Resource Name (ARN) of the snapshot.
        :param pulumi.Input[str] cluster_identifier: The cluster identifier for which you want a snapshot.
        :param pulumi.Input[str] kms_key_id: The Key Management Service (KMS) key ID of the encryption key that was used to encrypt data in the cluster from which the snapshot was taken.
        :param pulumi.Input[int] manual_snapshot_retention_period: The number of days that a manual snapshot is retained. If the value is `-1`, the manual snapshot is retained indefinitely. Valid values are -1 and between `1` and `3653`.
        :param pulumi.Input[str] owner_account: For manual snapshots, the Amazon Web Services account used to create or copy the snapshot. For automatic snapshots, the owner of the cluster. The owner can perform all snapshot actions, such as sharing a manual snapshot.
        :param pulumi.Input[str] snapshot_identifier: A unique identifier for the snapshot that you are requesting. This identifier must be unique for all snapshots within the Amazon Web Services account.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterSnapshotState.__new__(_ClusterSnapshotState)

        __props__.__dict__["arn"] = arn
        __props__.__dict__["cluster_identifier"] = cluster_identifier
        __props__.__dict__["kms_key_id"] = kms_key_id
        __props__.__dict__["manual_snapshot_retention_period"] = manual_snapshot_retention_period
        __props__.__dict__["owner_account"] = owner_account
        __props__.__dict__["snapshot_identifier"] = snapshot_identifier
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tags_all"] = tags_all
        return ClusterSnapshot(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Output[str]:
        """
        Amazon Resource Name (ARN) of the snapshot.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="clusterIdentifier")
    def cluster_identifier(self) -> pulumi.Output[str]:
        """
        The cluster identifier for which you want a snapshot.
        """
        return pulumi.get(self, "cluster_identifier")

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> pulumi.Output[str]:
        """
        The Key Management Service (KMS) key ID of the encryption key that was used to encrypt data in the cluster from which the snapshot was taken.
        """
        return pulumi.get(self, "kms_key_id")

    @property
    @pulumi.getter(name="manualSnapshotRetentionPeriod")
    def manual_snapshot_retention_period(self) -> pulumi.Output[Optional[int]]:
        """
        The number of days that a manual snapshot is retained. If the value is `-1`, the manual snapshot is retained indefinitely. Valid values are -1 and between `1` and `3653`.
        """
        return pulumi.get(self, "manual_snapshot_retention_period")

    @property
    @pulumi.getter(name="ownerAccount")
    def owner_account(self) -> pulumi.Output[str]:
        """
        For manual snapshots, the Amazon Web Services account used to create or copy the snapshot. For automatic snapshots, the owner of the cluster. The owner can perform all snapshot actions, such as sharing a manual snapshot.
        """
        return pulumi.get(self, "owner_account")

    @property
    @pulumi.getter(name="snapshotIdentifier")
    def snapshot_identifier(self) -> pulumi.Output[str]:
        """
        A unique identifier for the snapshot that you are requesting. This identifier must be unique for all snapshots within the Amazon Web Services account.
        """
        return pulumi.get(self, "snapshot_identifier")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> pulumi.Output[Mapping[str, str]]:
        """
        A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        return pulumi.get(self, "tags_all")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'InstancePlatform',
    'InstanceType',
    'PlacementStrategy',
    'ProtocolType',
    'Tenancy',
]


class InstancePlatform(str, Enum):
    LINUX_UNIX = "Linux/UNIX"
    RED_HAT_ENTERPRISE_LINUX = "Red Hat Enterprise Linux"
    SUSE_LINUX = "SUSE Linux"
    WINDOWS = "Windows"
    WINDOWS_WITH_SQL_SERVER = "Windows with SQL Server"
    WINDOWS_WITH_SQL_SERVER_ENTERPRISE = "Windows with SQL Server Enterprise"
    WINDOWS_WITH_SQL_SERVER_STANDARD = "Windows with SQL Server Standard"
    WINDOWS_WITH_SQL_SERVER_WEB = "Windows with SQL Server Web"


class InstanceType(str, Enum):
    A1_2_X_LARGE = "a1.2xlarge"
    A1_4_X_LARGE = "a1.4xlarge"
    A1_LARGE = "a1.large"
    A1_MEDIUM = "a1.medium"
    A1_METAL = "a1.metal"
    A1_X_LARGE = "a1.xlarge"
    C1_MEDIUM = "c1.medium"
    C1_X_LARGE = "c1.xlarge"
    C3_2_X_LARGE = "c3.2xlarge"
    C3_4_X_LARGE = "c3.4xlarge"
    C3_8_X_LARGE = "c3.8xlarge"
    C3_LARGE = "c3.large"
    C3_X_LARGE = "c3.xlarge"
    C4_2_X_LARGE = "c4.2xlarge"
    C4_4_X_LARGE = "c4.4xlarge"
    C4_8_X_LARGE = "c4.8xlarge"
    C4_LARGE = "c4.large"
    C4_X_LARGE = "c4.xlarge"
    C5_12_X_LARGE = "c5.12xlarge"
    C5_18_X_LARGE = "c5.18xlarge"
    C5_24_X_LARGE = "c5.24xlarge"
    C5_2_X_LARGE = "c5.2xlarge"
    C5_4_X_LARGE = "c5.4xlarge"
    C5_9_X_LARGE = "c5.9xlarge"
    C5_LARGE = "c5.large"
    C5_METAL = "c5.metal"
    C5_X_LARGE = "c5.xlarge"
    C5A_12_X_LARGE = "c5a.12xlarge"
    C5A_16_X_LARGE = "c5a.16xlarge"
    C5A_24_X_LARGE = "c5a.24xlarge"
    C5A_2_X_LARGE = "c5a.2xlarge"
    C5A_4_X_LARGE = "c5a.4xlarge"
    C5A_8_X_LARGE = "c5a.8xlarge"
    C5A_LARGE = "c5a.large"
    C5A_X_LARGE = "c5a.xlarge"
    C5AD_12_X_LARGE = "c5ad.12xlarge"
    C5AD_16_X_LARGE = "c5ad.16xlarge"
    C5AD_24_X_LARGE = "c5ad.24xlarge"
    C5AD_2_X_LARGE = "c5ad.2xlarge"
    C5AD_4_X_LARGE = "c5ad.4xlarge"
    C5AD_8_X_LARGE = "c5ad.8xlarge"
    C5AD_LARGE = "c5ad.large"
    C5AD_X_LARGE = "c5ad.xlarge"
    C5D_12_X_LARGE = "c5d.12xlarge"
    C5D_18_X_LARGE = "c5d.18xlarge"
    C5D_24_X_LARGE = "c5d.24xlarge"
    C5D_2_X_LARGE = "c5d.2xlarge"
    C5D_4_X_LARGE = "c5d.4xlarge"
    C5D_9_X_LARGE = "c5d.9xlarge"
    C5D_LARGE = "c5d.large"
    C5D_METAL = "c5d.metal"
    C5D_X_LARGE = "c5d.xlarge"
    C5N_18_X_LARGE = "c5n.18xlarge"
    C5N_2_X_LARGE = "c5n.2xlarge"
    C5N_4_X_LARGE = "c5n.4xlarge"
    C5N_9_X_LARGE = "c5n.9xlarge"
    C5N_LARGE = "c5n.large"
    C5N_METAL = "c5n.metal"
    C5N_X_LARGE = "c5n.xlarge"
    C6A_LARGE = "c6a.large"
    C6A_METAL = "c6a.metal"
    C6A_X_LARGE = "c6a.xlarge"
    C6A_2_X_LARGE = "c6a.2xlarge"
    C6A_4_X_LARGE = "c6a.4xlarge"
    C6A_8_X_LARGE = "c6a.8xlarge"
    C6A_12_X_LARGE = "c6a.12xlarge"
    C6A_16_X_LARGE = "c6a.16xlarge"
    C6A_24_X_LARGE = "c6a.24xlarge"
    C6A_32_X_LARGE = "c6a.32xlarge"
    C6A_48_X_LARGE = "c6a.48xlarge"
    C6G_12_X_LARGE = "c6g.12xlarge"
    C6G_16_X_LARGE = "c6g.16xlarge"
    C6G_2_X_LARGE = "c6g.2xlarge"
    C6G_4_X_LARGE = "c6g.4xlarge"
    C6G_8_X_LARGE = "c6g.8xlarge"
    C6G_LARGE = "c6g.large"
    C6G_MEDIUM = "c6g.medium"
    C6G_METAL = "c6g.metal"
    C6G_X_LARGE = "c6g.xlarge"
    C6GD_12_X_LARGE = "c6gd.12xlarge"
    C6GD_16_X_LARGE = "c6gd.16xlarge"
    C6GD_2_X_LARGE = "c6gd.2xlarge"
    C6GD_4_X_LARGE = "c6gd.4xlarge"
    C6GD_8_X_LARGE = "c6gd.8xlarge"
    C6GD_LARGE = "c6gd.large"
    C6GD_MEDIUM = "c6gd.medium"
    C6GD_METAL = "c6gd.metal"
    C6GD_X_LARGE = "c6gd.xlarge"
    C6I_LARGE = "c6i.large"
    C6I_X_LARGE = "c6i.xlarge"
    C6I_2_X_LARGE = "c6i.2xlarge"
    C6I_4_X_LARGE = "c6i.4xlarge"
    C6I_8_X_LARGE = "c6i.8xlarge"
    C6I_12_X_LARGE = "c6i.12xlarge"
    C6I_16_X_LARGE = "c6i.16xlarge"
    C6I_24_X_LARGE = "c6i.24xlarge"
    C6I_32_X_LARGE = "c6i.32xlarge"
    C6I_METAL = "c6i.metal"
    C6ID_LARGE = "c6id.large"
    C6ID_X_LARGE = "c6id.xlarge"
    C6ID_2_X_LARGE = "c6id.2xlarge"
    C6ID_4_X_LARGE = "c6id.4xlarge"
    C6ID_8_X_LARGE = "c6id.8xlarge"
    C6ID_12_X_LARGE = "c6id.12xlarge"
    C6ID_16_X_LARGE = "c6id.16xlarge"
    C6ID_24_X_LARGE = "c6id.24xlarge"
    C6ID_32_X_LARGE = "c6id.32xlarge"
    C6ID_METAL = "c6id.metal"
    CC2_8_X_LARGE = "cc2.8xlarge"
    D2_2_X_LARGE = "d2.2xlarge"
    D2_4_X_LARGE = "d2.4xlarge"
    D2_8_X_LARGE = "d2.8xlarge"
    D2_X_LARGE = "d2.xlarge"
    D3_2_X_LARGE = "d3.2xlarge"
    D3_4_X_LARGE = "d3.4xlarge"
    D3_8_X_LARGE = "d3.8xlarge"
    D3_X_LARGE = "d3.xlarge"
    D3EN_12_X_LARGE = "d3en.12xlarge"
    D3EN_2_X_LARGE = "d3en.2xlarge"
    D3EN_4_X_LARGE = "d3en.4xlarge"
    D3EN_6_X_LARGE = "d3en.6xlarge"
    D3EN_8_X_LARGE = "d3en.8xlarge"
    D3EN_X_LARGE = "d3en.xlarge"
    F1_16_X_LARGE = "f1.16xlarge"
    F1_2_X_LARGE = "f1.2xlarge"
    F1_4_X_LARGE = "f1.4xlarge"
    G2_2_X_LARGE = "g2.2xlarge"
    G2_8_X_LARGE = "g2.8xlarge"
    G3_16_X_LARGE = "g3.16xlarge"
    G3_4_X_LARGE = "g3.4xlarge"
    G3_8_X_LARGE = "g3.8xlarge"
    G3S_X_LARGE = "g3s.xlarge"
    G4AD_16_X_LARGE = "g4ad.16xlarge"
    G4AD_X_LARGE = "g4ad.xlarge"
    G4AD_2_X_LARGE = "g4ad.2xlarge"
    G4AD_4_X_LARGE = "g4ad.4xlarge"
    G4AD_8_X_LARGE = "g4ad.8xlarge"
    G4DN_12_X_LARGE = "g4dn.12xlarge"
    G4DN_16_X_LARGE = "g4dn.16xlarge"
    G4DN_2_X_LARGE = "g4dn.2xlarge"
    G4DN_4_X_LARGE = "g4dn.4xlarge"
    G4DN_8_X_LARGE = "g4dn.8xlarge"
    G4DN_METAL = "g4dn.metal"
    G4DN_X_LARGE = "g4dn.xlarge"
    H1_16_X_LARGE = "h1.16xlarge"
    H1_2_X_LARGE = "h1.2xlarge"
    H1_4_X_LARGE = "h1.4xlarge"
    H1_8_X_LARGE = "h1.8xlarge"
    I2_2_X_LARGE = "i2.2xlarge"
    I2_4_X_LARGE = "i2.4xlarge"
    I2_8_X_LARGE = "i2.8xlarge"
    I2_X_LARGE = "i2.xlarge"
    I3_16_X_LARGE = "i3.16xlarge"
    I3_2_X_LARGE = "i3.2xlarge"
    I3_4_X_LARGE = "i3.4xlarge"
    I3_8_X_LARGE = "i3.8xlarge"
    I3_LARGE = "i3.large"
    I3_X_LARGE = "i3.xlarge"
    I3_METAL = "i3.metal"
    I3EN_12_X_LARGE = "i3en.12xlarge"
    I3EN_24_X_LARGE = "i3en.24xlarge"
    I3EN_2_X_LARGE = "i3en.2xlarge"
    I3EN_3_X_LARGE = "i3en.3xlarge"
    I3EN_6_X_LARGE = "i3en.6xlarge"
    I3EN_LARGE = "i3en.large"
    I3EN_METAL = "i3en.metal"
    I3EN_X_LARGE = "i3en.xlarge"
    INF1_24_X_LARGE = "inf1.24xlarge"
    INF1_2_X_LARGE = "inf1.2xlarge"
    INF1_6_X_LARGE = "inf1.6xlarge"
    INF1_X_LARGE = "inf1.xlarge"
    M1_LARGE = "m1.large"
    M1_MEDIUM = "m1.medium"
    M1_SMALL = "m1.small"
    M1_X_LARGE = "m1.xlarge"
    M2_2_X_LARGE = "m2.2xlarge"
    M2_4_X_LARGE = "m2.4xlarge"
    M2_X_LARGE = "m2.xlarge"
    M3_2_X_LARGE = "m3.2xlarge"
    M3_LARGE = "m3.large"
    M3_MEDIUM = "m3.medium"
    M3_X_LARGE = "m3.xlarge"
    M4_10_X_LARGE = "m4.10xlarge"
    M4_16_X_LARGE = "m4.16xlarge"
    M4_2_X_LARGE = "m4.2xlarge"
    M4_4_X_LARGE = "m4.4xlarge"
    M4_LARGE = "m4.large"
    M4_X_LARGE = "m4.xlarge"
    M5_12_X_LARGE = "m5.12xlarge"
    M5_16_X_LARGE = "m5.16xlarge"
    M5_24_X_LARGE = "m5.24xlarge"
    M5_2_X_LARGE = "m5.2xlarge"
    M5_4_X_LARGE = "m5.4xlarge"
    M5_8_X_LARGE = "m5.8xlarge"
    M5_LARGE = "m5.large"
    M5_METAL = "m5.metal"
    M5_X_LARGE = "m5.xlarge"
    M5A_12_X_LARGE = "m5a.12xlarge"
    M5A_16_X_LARGE = "m5a.16xlarge"
    M5A_24_X_LARGE = "m5a.24xlarge"
    M5A_2_X_LARGE = "m5a.2xlarge"
    M5A_4_X_LARGE = "m5a.4xlarge"
    M5A_8_X_LARGE = "m5a.8xlarge"
    M5A_LARGE = "m5a.large"
    M5A_X_LARGE = "m5a.xlarge"
    M5AD_12_X_LARGE = "m5ad.12xlarge"
    M5AD_16_X_LARGE = "m5ad.16xlarge"
    M5AD_24_X_LARGE = "m5ad.24xlarge"
    M5AD_2_X_LARGE = "m5ad.2xlarge"
    M5AD_4_X_LARGE = "m5ad.4xlarge"
    M5AD_8_X_LARGE = "m5ad.8xlarge"
    M5AD_LARGE = "m5ad.large"
    M5AS_X_LARGE = "m5ad.xlarge"
    M5D_12_X_LARGE = "m5d.12xlarge"
    M5D_16_X_LARGE = "m5d.16xlarge"
    M5D_24_X_LARGE = "m5d.24xlarge"
    M5D_2_X_LARGE = "m5d.2xlarge"
    M5D_4_X_LARGE = "m5d.4xlarge"
    M5D_8_X_LARGE = "m5d.8xlarge"
    M5D_LARGE = "m5d.large"
    M5D_METAL = "m5d.metal"
    M5D_X_LARGE = "m5d.xlarge"
    M5DN_12_X_LARGE = "m5dn.12xlarge"
    M5DN_16_X_LARGE = "m5dn.16xlarge"
    M5DN_24_X_LARGE = "m5dn.24xlarge"
    M5DN_2_X_LARGE = "m5dn.2xlarge"
    M5DN_4_X_LARGE = "m5dn.4xlarge"
    M5DN_8_X_LARGE = "m5dn.8xlarge"
    M5DN_LARGE = "m5dn.large"
    M5DN_X_LARGE = "m5dn.xlarge"
    M5N_12_X_LARGE = "m5n.12xlarge"
    M5N_16_X_LARGE = "m5n.16xlarge"
    M5N_24_X_LARGE = "m5n.24xlarge"
    M5N_2_X_LARGE = "m5n.2xlarge"
    M5N_4_X_LARGE = "m5n.4xlarge"
    M5N_8_X_LARGE = "m5n.8xlarge"
    M5N_LARGE = "m5n.large"
    M5N_X_LARGE = "m5n.xlarge"
    M5ZN_12_X_LARGE = "m5zn.12xlarge"
    M5ZN_2_X_LARGE = "m5zn.2xlarge"
    M5ZN_3_X_LARGE = "m5zn.3xlarge"
    M5ZN_6_X_LARGE = "m5zn.6xlarge"
    M5ZN_LARGE = "m5zn.large"
    M5ZN_METAL = "m5zn.metal"
    M5ZN_X_LARGE = "m5zn.xlarge"
    M6A_LARGE = "m6a.large"
    M6A_METAL = "m6a.metal"
    M6A_X_LARGE = "m6a.xlarge"
    M6A_2_X_LARGE = "m6a.2xlarge"
    M6A_4_X_LARGE = "m6a.4xlarge"
    M6A_8_X_LARGE = "m6a.8xlarge"
    M6A_12_X_LARGE = "m6a.12xlarge"
    M6A_16_X_LARGE = "m6a.16xlarge"
    M6A_24_X_LARGE = "m6a.24xlarge"
    M6A_32_X_LARGE = "m6a.32xlarge"
    M6A_48_X_LARGE = "m6a.48xlarge"
    M6G_12_X_LARGE = "m6g.12xlarge"
    M6G_16_X_LARGE = "m6g.16xlarge"
    M6G_2_X_LARGE = "m6g.2xlarge"
    M6G_4_X_LARGE = "m6g.4xlarge"
    M6G_8_X_LARGE = "m6g.8xlarge"
    M6G_LARGE = "m6g.large"
    M6G_MEDIUM = "m6g.medium"
    M6G_METAL = "m6g.metal"
    M6G_X_LARGE = "m6g.xlarge"
    M6GD_12_X_LARGE = "m6gd.12xlarge"
    M6GD_16_X_LARGE = "m6gd.16xlarge"
    M6GD_2_X_LARGE = "m6gd.2xlarge"
    M6GD_4_X_LARGE = "m6gd.4xlarge"
    M6GD_8_X_LARGE = "m6gd.8xlarge"
    M6GD_LARGE = "m6gd.large"
    M6GD_MEDIUM = "m6gd.medium"
    M6GD_METAL = "m6gd.metal"
    M6GD_X_LARGE = "m6gd.xlarge"
    M6I_LARGE = "m6i.large"
    M6I_X_LARGE = "m6i.xlarge"
    M6I_2_X_LARGE = "m6i.2xlarge"
    M6I_4_X_LARGE = "m6i.4xlarge"
    M6I_8_X_LARGE = "m6i.8xlarge"
    M6I_12_X_LARGE = "m6i.12xlarge"
    M6I_16_X_LARGE = "m6i.16xlarge"
    M6I_24_X_LARGE = "m6i.24xlarge"
    M6I_32_X_LARGE = "m6i.32xlarge"
    M6I_METAL = "m6i.metal"
    M6ID_LARGE = "m6id.large"
    M6ID_X_LARGE = "m6id.xlarge"
    M6ID_2_X_LARGE = "m6id.2xlarge"
    M6ID_4_X_LARGE = "m6id.4xlarge"
    M6ID_8_X_LARGE = "m6id.8xlarge"
    M6ID_12_X_LARGE = "m6id.12xlarge"
    M6ID_16_X_LARGE = "m6id.16xlarge"
    M6ID_24_X_LARGE = "m6id.24xlarge"
    M6ID_32_X_LARGE = "m6id.32xlarge"
    M6ID_METAL = "m6id.metal"
    MAC1_METAL = "mac1.metal"
    P2_16_X_LARGE = "p2.16xlarge"
    P2_8_X_LARGE = "p2.8xlarge"
    P2_X_LARGE = "p2.xlarge"
    P3_16_X_LARGE = "p3.16xlarge"
    P3_2_X_LARGE = "p3.2xlarge"
    P3_8_X_LARGE = "p3.8xlarge"
    P3DN_24_X_LARGE = "p3dn.24xlarge"
    P4D_24_X_LARGE = "p4d.24xlarge"
    R3_2_X_LARGE = "r3.2xlarge"
    R3_4_X_LARGE = "r3.4xlarge"
    R3_8_X_LARGE = "r3.8xlarge"
    R3_LARGE = "r3.large"
    R3_X_LARGE = "r3.xlarge"
    R4_16_X_LARGE = "r4.16xlarge"
    R4_2_X_LARGE = "r4.2xlarge"
    R4_4_X_LARGE = "r4.4xlarge"
    R4_8_X_LARGE = "r4.8xlarge"
    R4_LARGE = "r4.large"
    R4_X_LARGE = "r4.xlarge"
    R5_12_X_LARGE = "r5.12xlarge"
    R5_16_X_LARGE = "r5.16xlarge"
    R5_24_X_LARGE = "r5.24xlarge"
    R5_2_X_LARGE = "r5.2xlarge"
    R5_4_X_LARGE = "r5.4xlarge"
    R5_8_X_LARGE = "r5.8xlarge"
    R5_LARGE = "r5.large"
    R5_METAL = "r5.metal"
    R5_X_LARGE = "r5.xlarge"
    R5A_12_X_LARGE = "r5a.12xlarge"
    R5A_16_X_LARGE = "r5a.16xlarge"
    R5A_24_X_LARGE = "r5a.24xlarge"
    R5A_2_X_LARGE = "r5a.2xlarge"
    R5A_4_X_LARGE = "r5a.4xlarge"
    R5A_8_X_LARGE = "r5a.8xlarge"
    R5A_LARGE = "r5a.large"
    R5A_X_LARGE = "r5a.xlarge"
    R5AD_12_X_LARGE = "r5ad.12xlarge"
    R5AD_16_X_LARGE = "r5ad.16xlarge"
    R5AD_24_X_LARGE = "r5ad.24xlarge"
    R5AD_2_X_LARGE = "r5ad.2xlarge"
    R5AD_4_X_LARGE = "r5ad.4xlarge"
    R5AD_8_X_LARGE = "r5ad.8xlarge"
    R5AD_LARGE = "r5ad.large"
    R5AD_X_LARGE = "r5ad.xlarge"
    R5B_12_X_LARGE = "r5b.12xlarge"
    R5B_16_X_LARGE = "r5b.16xlarge"
    R5B_24_X_LARGE = "r5b.24xlarge"
    R5B_2_X_LARGE = "r5b.2xlarge"
    R5B_4_X_LARGE = "r5b.4xlarge"
    R5B_8_X_LARGE = "r5b.8xlarge"
    R5B_LARGE = "r5b.large"
    R5B_METAL = "r5b.metal"
    R5B_X_LARGE = "r5b.xlarge"
    R5D_12_X_LARGE = "r5d.12xlarge"
    R5D_16_X_LARGE = "r5d.16xlarge"
    R5D_24_X_LARGE = "r5d.24xlarge"
    R5D_2_X_LARGE = "r5d.2xlarge"
    R5D_4_X_LARGE = "r5d.4xlarge"
    R5D_8_X_LARGE = "r5d.8xlarge"
    R5D_LARGE = "r5d.large"
    R5D_METAL = "r5d.metal"
    R5D_X_LARGE = "r5d.xlarge"
    R5DN_12_X_LARGE = "r5dn.12xlarge"
    R5DN_16_X_LARGE = "r5dn.16xlarge"
    R5DN_24_X_LARGE = "r5dn.24xlarge"
    R5DN_2_X_LARGE = "r5dn.2xlarge"
    R5DN_4_X_LARGE = "r5dn.4xlarge"
    R5DN_8_X_LARGE = "r5dn.8xlarge"
    R5DN_LARGE = "r5dn.large"
    R5DN_X_LARGE = "r5dn.xlarge"
    R5N_12_X_LARGE = "r5n.12xlarge"
    R5N_16_X_LARGE = "r5n.16xlarge"
    R5N_24_X_LARGE = "r5n.24xlarge"
    R5N_2_X_LARGE = "r5n.2xlarge"
    R5N_4_X_LARGE = "r5n.4xlarge"
    R5N_8_X_LARGE = "r5n.8xlarge"
    R5N_LARGE = "r5n.large"
    R5N_X_LARGE = "r5n.xlarge"
    R6G_12_X_LARGE = "r6g.12xlarge"
    R6G_16_X_LARGE = "r6g.16xlarge"
    R6G_2_X_LARGE = "r6g.2xlarge"
    R6G_4_X_LARGE = "r6g.4xlarge"
    R6G_8_X_LARGE = "r6g.8xlarge"
    R6G_LARGE = "r6g.large"
    R6G_MEDIUM = "r6g.medium"
    R6G_METAL = "r6g.metal"
    R6G_X_LARGE = "r6g.xlarge"
    R6GD_12_X_LARGE = "r6gd.12xlarge"
    R6GD_16_X_LARGE = "r6gd.16xlarge"
    R6GD_2_X_LARGE = "r6gd.2xlarge"
    R6GD_4_X_LARGE = "r6gd.4xlarge"
    R6GD_8_X_LARGE = "r6gd.8xlarge"
    R6GD_LARGE = "r6gd.large"
    R6GD_MEDIUM = "r6gd.medium"
    R6GD_METAL = "r6gd.metal"
    R6GD_X_LARGE = "r6gd.xlarge"
    R6I_LARGE = "r6i.large"
    R6I_X_LARGE = "r6i.xlarge"
    R6I_2_X_LARGE = "r6i.2xlarge"
    R6I_4_X_LARGE = "r6i.4xlarge"
    R6I_8_X_LARGE = "r6i.8xlarge"
    R6I_12_X_LARGE = "r6i.12xlarge"
    R6I_16_X_LARGE = "r6i.16xlarge"
    R6I_24_X_LARGE = "r6i.24xlarge"
    R6I_32_X_LARGE = "r6i.32xlarge"
    R6I_METAL = "r6i.metal"
    R6ID_LARGE = "r6id.large"
    R6ID_X_LARGE = "r6id.xlarge"
    R6ID_2_X_LARGE = "r6id.2xlarge"
    R6ID_4_X_LARGE = "r6id.4xlarge"
    R6ID_8_X_LARGE = "r6id.8xlarge"
    R6ID_12_X_LARGE = "r6id.12xlarge"
    R6ID_16_X_LARGE = "r6id.16xlarge"
    R6ID_24_X_LARGE = "r6id.24xlarge"
    R6ID_32_X_LARGE = "r6id.32xlarge"
    R6ID_METAL = "r6id.metal"
    T1_MICRO = "t1.micro"
    T2_2_X_LARGE = "t2.2xlarge"
    T2_LARGE = "t2.large"
    T2_MEDIUM = "t2.medium"
    T2_MICRO = "t2.micro"
    T2_NANO = "t2.nano"
    T2_SMALL = "t2.small"
    T2_X_LARGE = "t2.xlarge"
    T3_2_X_LARGE = "t3.2xlarge"
    T3_LARGE = "t3.large"
    T3_MEDIUM = "t3.medium"
    T3_MICRO = "t3.micro"
    T3_NANO = "t3.nano"
    T3_SMALL = "t3.small"
    T3_X_LARGE = "t3.xlarge"
    T3A_2_X_LARGE = "t3a.2xlarge"
    T3A_LARGE = "t3a.large"
    T3A_MEDIUM = "t3a.medium"
    T3A_MICRO = "t3a.micro"
    T3A_NANO = "t3a.nano"
    T3A_SMALL = "t3a.small"
    T3A_X_LARGE = "t3a.xlarge"
    T4G_2_X_LARGE = "t4g.2xlarge"
    T4G_LARGE = "t4g.large"
    T4G_MEDIUM = "t4g.medium"
    T4G_MICRO = "t4g.micro"
    T4G_NANO = "t4g.nano"
    T4G_SMALL = "t4g.small"
    T4G_X_LARGE = "t4g.xlarge"
    X1_16_X_LARGE = "x1.16xlarge"
    X1_32_X_LARGE = "x1.32xlarge"
    X1E_16_X_LARGE = "x1e.16xlarge"
    X1E_2_X_LARGE = "x1e.2xlarge"
    X1E_32_X_LARGE = "x1e.32xlarge"
    X1E_4_X_LARGE = "x1e.4xlarge"
    X1E_8_X_LARGE = "x1e.8xlarge"
    X1E_X_LARGE = "x1e.xlarge"
    Z1D_12_X_LARGE = "z1d.12xlarge"
    Z1D_2_X_LARGE = "z1d.2xlarge"
    Z1D_3_X_LARGE = "z1d.3xlarge"
    Z1D_6_X_LARGE = "z1d.6xlarge"
    Z1D_LARGE = "z1d.large"
    Z1D_METAL = "z1d.metal"
    Z1D_X_LARGE = "z1d.xlarge"
    U_12TB1_METAL = "u-12tb1.metal"
    U_6TB1_METAL = "u-6tb1.metal"
    U_9TB1_METAL = "u-9tb1.metal"
    HS1_8_X_LARGE = "hs1.8xlarge"


class PlacementStrategy(str, Enum):
    """
    The strategy of the placement group determines how the instances are organized within the group.
    See https://docs.aws.amazon.com/cli/latest/reference/ec2/create-placement-group.html
    """
    SPREAD = "spread"
    """
    A `spread` placement group places instances on distinct hardware.
    """
    CLUSTER = "cluster"
    """
    A `cluster` placement group is a logical grouping of instances within a single
    Availability Zone that benefit from low network latency, high network throughput.
    """


class ProtocolType(str, Enum):
    ALL = "all"
    TCP = "tcp"
    UDP = "udp"
    ICMP = "icmp"


class Tenancy(str, Enum):
    DEFAULT = "default"
    DEDICATED = "dedicated"
